pilot.filemanagement.s3_adaptor.S3FileAdaptor

Package pilot :: Package filemanagement :: Module s3_adaptor :: Class S3FileAdaptor |

# Class S3FileAdaptor

source code

    BigData File Management for Pilot Data
    Supports pilot data on top of S3 and Eucalyptus Walrus

        s3://
        walrus://<endpoint-ip>

    Amazon S3 supported regions:

        Default is an empty string "" => us-east-1

        'ap-northeast-1'
        'ap-southeast-1'
        'ap-southeast-2'
        'EU'
        'sa-east-1'
        'us-west-1'
        'us-west-2'

Instance Methods
__init__(self, resource_url, security_context=None, pilot_data_description=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
get_security_context(self) Returns security context that needs to be available on the distributed node in order to access this Pilot Data | source code
initialize_pilotdata(self) | source code
get_pilotdata_size(self) | source code
delete_pilotdata(self) | source code
get_state(self) | source code
create_du(self, du_id) | source code
put_du(self, du) | source code
get_du(self, du, target_url) | source code
copy_du(self, du, pd_new) | source code
remove_du(self, du) | source code
transfer(self, source_url, target_url) | source code
create_remote_directory(self, target_url) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, resource_url, security_context=None, pilot_data_description=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)